@@ -610,7 +610,8 @@ class UTADatabase:
             {aln_method}
             AND {start_pos} BETWEEN {pos_q}
             AND {end_pos} BETWEEN {pos_q}
-            ORDER BY alt_ac;
+            ORDER BY (CAST(SUBSTR(alt_ac, position('.' in alt_ac) + 1,
+                LENGTH(alt_ac)) AS INT))
             """
         )
         result = await self.execute_query(query)
@@ -714,7 +715,8 @@ class UTADatabase:
     async def get_genomic_tx_data(
         self, tx_ac: str, pos: Tuple[int, int],
         annotation_layer: Union[AnnotationLayer.CDNA, AnnotationLayer.GENOMIC] = AnnotationLayer.CDNA,  # noqa: E501
-        alt_ac: Optional[str] = None
+        alt_ac: Optional[str] = None,
+        target_genome_assembly: Assembly = Assembly.GRCH38
     ) -> Optional[Dict]:
         """Get transcript mapping to genomic data.
 
@@ -723,6 +725,8 @@ class UTADatabase:
         :param Union[AnnotationLayer.CDNA, AnnotationLayer.GENOMIC] annotation_layer:
             Annotation layer for `ac` and `pos`
         :param Optional[str] alt_ac: Accession on g. coordinate
+        :param Assembly target_genome_assembly: Genome assembly to get genomic data for.
+            If `alt_ac` is provided, it will return the associated assembly.
         :return: Gene, Transcript accession and position change,
             Altered transcript accession and position change, Strand
         """
@@ -731,7 +735,11 @@ class UTADatabase:
             alt_ac=alt_ac)
         if not results:
             return None
-        result = results[-1]
+
+        if alt_ac or target_genome_assembly == Assembly.GRCH38:
+            result = results[-1]
+        else:
+            result = results[0]
 
         data = self.data_from_result(result)
         if not data:
